@@ -16,7 +16,7 @@ class Command(BaseYarnCommand):
         if self._is_single_command('install', args):
             self._install([])
         else:
-            yarn_adapter.call_bower(args)
+            yarn_adapter.call_yarn(args)
 
     def _is_single_command(self, name, args):
         return len(args) == 1 and args[0] == name
